/***************************************************
//Web: http://www.buydisplay.com
EastRising Technology Co.,LTD
****************************************************/
#include "ER-EPD027-2.h"
#include "Debug.h"



/******************************************************************************
function :	Software reset
parameter:
******************************************************************************/
static void EPD_Reset(void)
{
    DEV_Digital_Write(EPD_RST_PIN, 1);
    DEV_Delay_ms(200);
    DEV_Digital_Write(EPD_RST_PIN, 0);
    DEV_Delay_ms(200);
    DEV_Digital_Write(EPD_RST_PIN, 1);
    DEV_Delay_ms(200);
}

/******************************************************************************
function :	send command
parameter:
     Reg : Command register
******************************************************************************/
static void EPD_SendCommand(UBYTE Reg)
{
    DEV_Digital_Write(EPD_DC_PIN, 0);
    DEV_Digital_Write(EPD_CS_PIN, 0);
    DEV_SPI_WriteByte(Reg);
    DEV_Digital_Write(EPD_CS_PIN, 1);
}

/******************************************************************************
function :	send data
parameter:
    Data : Write data
******************************************************************************/
static void EPD_SendData(UBYTE Data)
{
    DEV_Digital_Write(EPD_DC_PIN, 1);
    DEV_Digital_Write(EPD_CS_PIN, 0);
    DEV_SPI_WriteByte(Data);
    DEV_Digital_Write(EPD_CS_PIN, 1);
}

/******************************************************************************
function :	Wait until the busy_pin goes LOW
parameter:
******************************************************************************/
void EPD_WaitUntilIdle(void)
{
    Debug("e-Paper busy\r\n");
    while(DEV_Digital_Read(EPD_BUSY_PIN) == 0) {      //0: busy, 1: idle
        DEV_Delay_ms(100);
    }    
    Debug("e-Paper busy release\r\n");
}


/******************************************************************************
function :	Initialize the e-Paper register
parameter:
******************************************************************************/
UBYTE EPD_Init(void)
{
    EPD_Reset();
    EPD_SendCommand(POWER_SETTING);
    EPD_SendData(0x03);                  // VDS_EN, VDG_EN
    EPD_SendData(0x00);                  // VCOM_HV, VGHL_LV[1], VGHL_LV[0]
    EPD_SendData(0x2b);                  // VDH
    EPD_SendData(0x2b);                  // VDL
    EPD_SendData(0x09);                  // VDHR
    
    EPD_SendCommand(BOOSTER_SOFT_START);
    EPD_SendData(0x17);
    EPD_SendData(0x17);
    EPD_SendData(0x17);


    EPD_SendCommand(PARTIAL_DISPLAY_REFRESH);
    EPD_SendData(0x00);
    EPD_SendCommand(POWER_ON);
    EPD_WaitUntilIdle();

    EPD_SendCommand(PANEL_SETTING);
    EPD_SendData(0x0F);        //KW-BF   KWR-AF    BWROTP 0f


    EPD_SendCommand(TCON_RESOLUTION);
    EPD_SendData(0x16<<3);
    EPD_SendData(0x01);
    EPD_SendData(0x08);
    
    EPD_SendCommand( VCOM_AND_DATA_INTERVAL_SETTING); 
    EPD_SendData(0x87);
  

    
    return 0;
}

/******************************************************************************
function :	Clear screen
parameter:
******************************************************************************/
void EPD_Clear(void)
{    
    UWORD Width, Height,j,i;
    Width = (EPD_WIDTH % 8 == 0)? (EPD_WIDTH / 8 ): (EPD_WIDTH / 8 + 1);
    Height = EPD_HEIGHT;

    EPD_SendCommand(DATA_START_TRANSMISSION_1);
    for (j = 0; j < Height; j++) {
        for (i = 0; i < Width; i++) {
            EPD_SendData(0X00);
        }
    }
    EPD_SendCommand(DATA_STOP);

    EPD_SendCommand(DATA_START_TRANSMISSION_2);
    for (j = 0; j < Height; j++) {
        for (i = 0; i < Width; i++) {
            EPD_SendData(0X00);
        }
    }
    EPD_SendCommand(DATA_STOP);
    
    EPD_SendCommand(DISPLAY_REFRESH);
    EPD_WaitUntilIdle();
}

/******************************************************************************
function :	Sends the image buffer in RAM to e-Paper and displays
parameter:
******************************************************************************/
void EPD_Display(UBYTE *Imageblack, UBYTE *Imagered)
{
    UWORD Width, Height,j,i;
    Width = (EPD_WIDTH % 8 == 0)? (EPD_WIDTH / 8 ): (EPD_WIDTH / 8 + 1);
    Height = EPD_HEIGHT;
    
    EPD_SendCommand(DATA_START_TRANSMISSION_1);
    for (j = 0; j < Height; j++) {
        for (i = 0; i < Width; i++) {
            EPD_SendData(Imageblack[i + j * Width]);
        }
    }
    EPD_SendCommand(DATA_STOP);
    
    EPD_SendCommand(DATA_START_TRANSMISSION_2);
    for (j = 0; j < Height; j++) {
        for (i = 0; i < Width; i++) {
            EPD_SendData(Imagered[i + j * Width]);
        }
    }
    EPD_SendCommand(DATA_STOP);
    
    EPD_SendCommand(DISPLAY_REFRESH);
    EPD_WaitUntilIdle();
}

/******************************************************************************
function :	Enter sleep mode
parameter:
******************************************************************************/
void EPD_Sleep(void)
{

    EPD_SendCommand(0X02);  	//power off
    EPD_SendCommand(0X07);  	//deep sleep
    EPD_SendData(0xA5);
}
